from setuptools import setup

setup(name='dist17',
      version='0.1',
      description='Gaussian and Binomial distributions',
      author='Donald Kelly',
      author_email='myemail017@gmail.com',
      url='',
      packages=['distributions'],
      zip_safe=False)